import {
  Button,
  Card,
  Col,
  Form,
  Grid,
  InputNumber,
  Row,
  Select,
  Slider,
} from "antd";
import { useForm } from "antd/es/form/Form";
import { useEffect, useState } from "react";

const { useBreakpoint } = Grid;

const Constants = {
  DISTANCE: {
    MIN: 0,
    MAX: 100,
  },
  ACCELERATION: {
    MIN: 0,
    MAX: 100,
  },
  DURATION: {
    MIN: 1,
    MAX: 60,
  },
};

function App() {
  const screens = useBreakpoint();
  const [form] = useForm();

  const [distance, setDistance] = useState([20, 50]);
  const [acceleration, setAcceleration] = useState(0);

  useEffect(() => {
    // todo: fetch to esp to get current values
  }, []);

  return (
    <div
      style={{
        display: "flex",
        flexDirection: "column",
        alignItems: "center",
        overflow: "auto",
        marginTop: 60,
        marginBottom: 60,
      }}
    >
      <Card
        title="Kamera Slider"
        style={{
          width: "90%",
          maxWidth: 800,
        }}
      >
        <Form
          form={form}
          layout="vertical"
          onFinish={() => {
            console.log("finish");

            // todo: fetch to update values
          }}
        >
          <Form.Item name="distance" label="Distanz">
            <Row>
              <Col xs={24} md={4}>
                <InputNumber
                  min={Constants.DISTANCE.MIN}
                  max={Constants.DISTANCE.MAX}
                  value={distance[0]}
                  step={1}
                  onChange={(value) =>
                    setDistance((newDistance) => {
                      const newData = [...newDistance];

                      newData[0] = value;

                      return newData;
                    })
                  }
                />
              </Col>

              <Col xs={24} md={16}>
                <Slider
                  range
                  defaultValue={[20, 50]}
                  marks={{ 0: "0", 100: "100" }}
                  min={Constants.DISTANCE.MIN}
                  max={Constants.DISTANCE.MAX}
                  value={distance}
                  onChange={(values) => setDistance(values)}
                />
              </Col>

              <Col xs={24} md={4}>
                <InputNumber
                  min={Constants.DISTANCE.MIN}
                  max={Constants.DISTANCE.MAX}
                  style={{
                    margin: screens.md ? "0 26px" : "",
                  }}
                  value={distance[1]}
                  step={1}
                  onChange={(value) =>
                    setDistance((newDistance) => {
                      const newData = [...newDistance];

                      newData[1] = value;

                      return newData;
                    })
                  }
                />
              </Col>
            </Row>
          </Form.Item>

          <Form.Item name="duration" label="Dauer" initialValue={5}>
            <InputNumber
              step={1}
              min={Constants.DURATION.MIN}
              max={Constants.DURATION.MAX}
              addonAfter={
                <Select
                  defaultValue="seconds"
                  style={{
                    width: 120,
                  }}
                >
                  <Select.Option value="seconds">Sekunden</Select.Option>
                  <Select.Option value="minutes">Minuten</Select.Option>
                </Select>
              }
            />
          </Form.Item>

          <Form.Item name="acceleration" label="Beschleunigung">
            <Row>
              <Col xs={24} md={20}>
                <Slider
                  defaultValue={20}
                  marks={{ 0: "0", 100: "100" }}
                  min={Constants.ACCELERATION.MIN}
                  max={Constants.ACCELERATION.MAX}
                  value={acceleration}
                  onChange={(value) => setAcceleration(value)}
                />
              </Col>

              <Col xs={24} md={4}>
                <InputNumber
                  min={Constants.ACCELERATION.MIN}
                  max={Constants.ACCELERATION.MAX}
                  style={{
                    margin: screens.md ? "0 26px" : "",
                  }}
                  value={acceleration}
                  onChange={(value) => setAcceleration(value)}
                />
              </Col>
            </Row>
          </Form.Item>

          <Form.Item>
            <Button type="primary" htmlType="submit" block>
              Speichern
            </Button>
          </Form.Item>
        </Form>
      </Card>
    </div>
  );
}

export default App;
